@@ -104,3 +104,15 @@ class BackendBase(with_metaclass(ABCMeta, object)):
 
         :rtype: m3_gar_client.data.House
         """
+
+    @abstractmethod
+    def get_stead(self, stead_id, timeout=None):
+        """Возвращает информацию о земельном участке по его ID в ГАР.
+
+        Args:
+            stead_id: ID земельного участка.
+            timeout: Timeout запросов к серверу ГАР в секундах.
+
+        Returns:
+            Объект m3_gar_client.data.House
+        """
