@@ -3,36 +3,39 @@ from abc import (
     ABCMeta,
     abstractmethod,
 )
-from copy import (
-    deepcopy,
-)
 from itertools import (
     chain,
     count,
 )
 
-from six import with_metaclass
-from six import text_type
-from six import iteritems
+from six import (
+    with_metaclass,
+    text_type,
+    iteritems,
+)
 from six.moves import (
     http_client,
     map,
     range,
 )
 
-from m3_gar_client.backends.m3_rest_gar.proxy.server import (
-    server,
-)
 from m3_gar_constants import (
     DEFAULT_PAGE_LIMIT,
     GAR_HIERARCHY_MUN,
     GAR_LEVELS_PLACE,
     GAR_LEVELS_STREET,
 )
+
+
+from m3_gar_client.backends.m3_rest_gar.proxy.server import (
+    server,
+)
 from m3_gar_client.data import (
     AddressObject,
+    Apartment,
     House,
     ObjectMapper,
+    Stead,
 )
 from m3_gar_client.utils import (
     cached_property,
@@ -43,11 +46,9 @@ from m3_gar_client.utils import (
 # Обёртки над данными, поступающими с сервера m3-rest-gar.
 
 class AddressObjectMapper(ObjectMapper):
-    """
-    Обертка над данными сервера m3-rest-gar об адресных объектах.
+    """Обертка над данными сервера m3-rest-gar об адресных объектах.
 
-    Предназначена для использования при создании экземпляров
-    :class:`m3_gar_client.data.AddressObject`.
+    Предназначена для использования при создании экземпляров.
     """
 
     fields_map = {
@@ -88,8 +89,7 @@ class AddressObjectMapper(ObjectMapper):
 class HouseMapper(ObjectMapper):
     """Обертка над данными сервера m3-rest-gar об адресных объектах.
 
-    Предназначена для использования при создании экземпляров
-    :class:`m3_gar_client.data.House`.
+    Предназначена для использования при создании экземпляров.
     """
 
     fields_map = {
@@ -114,18 +114,67 @@ class HouseMapper(ObjectMapper):
         'adm_parent_guid': 'hierarchy__adm__parentobjid__objectguid',
         'mun_parent_obj_id': 'hierarchy__mun__parentobjid__objectid',
         'mun_parent_guid': 'hierarchy__mun__parentobjid__objectguid',
+        'level': 'hierarchy__mun__objectid__levelid',
         'number': 'number',
         'house_type': 'housetype__shortname',
+        'house_type_full': 'housetype__name',
         'building_type': 'addtype1__shortname',
+        'building_type_full': 'addtype1__name',
         'structure_type': 'addtype2__shortname',
+        'structure_type_full': 'addtype2__name',
     }
 
     assert set(fields_map) == set(House.fields)
 
 
+class SteadMapper(ObjectMapper):
+    """Обертка над данными сервера m3-rest-gar об адресных объектах."""
+
+    fields_map = {
+        'id': 'id',
+        'guid': 'objectguid',
+        'obj_id': 'objectid',
+        'ifns_fl_code': 'params__IFNSFL__value',
+        'ifns_fl_territorial_district_code': 'params__territorialifnsflcode__value',
+        'ifns_ul_code': 'params__IFNSUL__value',
+        'ifns_ul_territorial_district_code': 'params__territorialifnsulcode__value',
+        'okato': 'params__OKATO__value',
+        'oktmo': 'params__OKTMO__value',
+        'postal_code': 'params__PostIndex__value',
+        'house_number': 'number',
+        'date_of_update': 'updatedate',
+        'date_of_creation': 'startdate',
+        'date_of_end': 'enddate',
+        'region_code': 'region_code',
+        'adm_parent_obj_id': 'hierarchy__adm__parentobjid__objectid',
+        'adm_parent_guid': 'hierarchy__adm__parentobjid__objectguid',
+        'mun_parent_obj_id': 'hierarchy__mun__parentobjid__objectid',
+        'mun_parent_guid': 'hierarchy__mun__parentobjid__objectguid',
+        'level': 'hierarchy__mun__objectid__levelid',
+        'number': 'number',
+    }
+
+
+class ApartmentMapper(ObjectMapper):
+    """Обертка над данными сервера m3-rest-gar о помещениях."""
+
+    fields_map = {
+        'id': 'id',
+        'guid': 'objectguid',
+        'obj_id': 'objectid',
+        'number': 'number',
+        'apart_type': 'aparttype__name',
+        'adm_parent_obj_id': 'hierarchy__adm__parentobjid__objectid',
+        'adm_parent_guid': 'hierarchy__adm__parentobjid__objectguid',
+        'mun_parent_obj_id': 'hierarchy__mun__parentobjid__objectid',
+        'mun_parent_guid': 'hierarchy__mun__parentobjid__objectguid',
+        'level': 'hierarchy__mun__objectid__levelid',
+    }
+
+
 class UIAddressObjectMapper(ObjectMapper):
-    """
-    Обертка над данными сервера m3-rest-gar об адресных объектах.
+    """Обертка над данными сервера m3-rest-gar об адресных объектах.
+
     Предназначена для использования в UI.
     """
 
@@ -142,8 +191,8 @@ class UIAddressObjectMapper(ObjectMapper):
 
 
 class UIHouseMapper(ObjectMapper):
-    """
-    Обертка над данными сервера m3-rest-gar о зданиях.
+    """Обертка над данными сервера m3-rest-gar о зданиях.
+
     Предназначена для использования в UI.
     """
 
@@ -160,8 +209,8 @@ class UIHouseMapper(ObjectMapper):
 
 
 class UISteadMapper(ObjectMapper):
-    """
-    Обертка над данными сервера m3-rest-gar о земельных участках.
+    """Обертка над данными сервера m3-rest-gar о земельных участках.
+
     Предназначена для использования в UI.
     """
 
@@ -176,16 +225,14 @@ class UISteadMapper(ObjectMapper):
 
 
 class LoaderBase(with_metaclass(ABCMeta, object)):
-    """
-    Базовый класс для загрузчиков объектов ГАР.
+    """Базовый класс для загрузчиков объектов ГАР.
+
+    Attributes:
+        filter_string: Строка для фильтрации объектов.
+        timeout: Timeout запросов к серверу ГАР в секундах.
     """
 
     def __init__(self, filter_string, **kwargs):
-        """Инициализация экземпляра класса.
-
-        :param unicode filter_string: Строка для фильтрации объектов.
-        :param float timeout: Timeout запросов к серверу ГАР в секундах.
-        """
         self.filter_string = filter_string
         self.timeout = kwargs.get('timeout')
         self.exact = kwargs.get('exact', False)
@@ -193,33 +240,23 @@ class LoaderBase(with_metaclass(ABCMeta, object)):
     @property
     @abstractmethod
     def _path(self):
-        """Путь к ресурсу API сервера ГАР.
-
-        :rtype: str
-        """
+        """Путь к ресурсу API сервера ГАР."""
 
     @cached_property
     def _fields(self):
-        """Имена полей, подлежащих загрузке.
+        """Имена полей, подлежащих загрузке."""
 
-        :rtype: tuple
-        """
         return list(self._mapper_class.fields_map.keys())
 
     @property
     @abstractmethod
     def _mapper_class(self):
-        """Класс, преобразующий имена полей.
-
-        ::rtype: m3_gar_client.data.ObjectMapper
-        """
+        """Класс, преобразующий имена полей."""
 
     @property
     def _filter_param(self):
-        """Query-параметр для фильтрации.
+        """Query-параметр для фильтрации."""
 
-        :rtype: str
-        """
         return 'name'
 
     def _load_page(self, params, page):
@@ -237,7 +274,8 @@ class LoaderBase(with_metaclass(ABCMeta, object)):
     def _process_object_data(self, drf_object_data):
         """Выполняет дополнительную обработку данных объекта ГАР.
 
-        :param dict drf_object_data: Данные объекта ГАР, полученные с сервера m3-rest-gar.
+        Args:
+            drf_object_data: Данные объекта ГАР, полученные с сервера m3-rest-gar.
         """
         return map_object_data(self._mapper_class, drf_object_data)
 
@@ -246,28 +284,20 @@ class LoaderBase(with_metaclass(ABCMeta, object)):
 
         Полученные данные включаются в результат загрузки.
 
-        :param dict object_data: Данные объекта, полученные с сервера ГАР и
-            прошедшие обработку в методе ``_process_object_data``.
-
-        :rtype: dict
+        Args:
+            object_data: Данные объекта, полученные с сервера ГАР и прошедшие обработку в методе
+                         ``_process_object_data``.
         """
-        return {
-            field: object_data[field]
-            for field in self._fields
-        }
+
+        return {field: object_data[field] for field in self._fields}
 
     @abstractmethod
     def _filter(self, object_data):
-        """Возвращает True, если объект ГАР должен попасть в загрузку.
-
-        :rtype: bool
-        """
+        """Возвращает True, если объект ГАР должен попасть в загрузку."""
 
     def _get_params(self):
-        """Возвращает параметры запроса к серверу ГАР.
+        """Возвращает параметры запроса к серверу ГАР."""
 
-        :rtype: dict
-        """
         filter_param = self._filter_param
 
         if self.exact:
@@ -282,11 +312,10 @@ class LoaderBase(with_metaclass(ABCMeta, object)):
     def load_raw(self, page=None):
         """Возвращает данные адресных объектов в исходном виде.
 
-        :param int page: Номера страницы для загрузки данных. Значение ``None``
-            указывает на необходимость загрузки всех страниц.
-
-        :rtype: generator
+        Args:
+            page: Номера страницы для загрузки данных. ``None`` указывает на необходимость загрузки всех страниц.
         """
+
         from django.conf import (
             settings,
         )
@@ -317,35 +346,36 @@ class LoaderBase(with_metaclass(ABCMeta, object)):
     def load_results(self, page=None):
         """Возвращает данные в соответствии с параметрами загрузчика.
 
-        :param int page: Номера страницы для загрузки данных. Значение ``None``
-            указывает на необходимость загрузки всех страниц.
-
-        :rtype: itertools.imap
+        Args:
+            page: Номера страницы для загрузки данных. ``None`` указывает на необходимость загрузки всех страниц.
         """
+
         return map(self._build_result, self.load_raw(page))
 
     @abstractmethod
     def _sort_key(self, object_data):
         """Возвращает значение ключа для сортировки результатов загрузки.
 
-        :param dict object_data: Данные загруженного объекта ГАР.
+        Args:
+            object_data: Данные загруженного объекта ГАР.
         """
 
     def _process_result(self, data):
         """Обработка полученных после загрузки данных.
 
-        :param tuple data: Кортеж словарей с данными загруженных объектов ГАР.
+        Args:
+            data: Кортеж словарей с данными загруженных объектов ГАР.
         """
+
         return sorted(data, key=self._sort_key)
 
     def load(self, page=None):
         """Загружает данные с сервера ГАР.
 
-        :param int page: Номера страницы для загрузки данных. Значение ``None``
-            указывает на необходимость загрузки всех страниц.
-
-        :rtype: collections.Iterable
+        Args:
+            page: Номера страницы для загрузки данных. ``None`` указывает на необходимость загрузки всех страниц.
         """
+
         data = tuple(self.load_results(page))
         result = self._process_result(data)
 
@@ -353,14 +383,12 @@ class LoaderBase(with_metaclass(ABCMeta, object)):
 
 
 class ParentFilterMixin(object):
-    """
-    Миксин для загрузчиков, которые используют id родительского объекта в запросах к серверу ГАР
-    """
+    """Миксин для загрузчиков, которые используют id родительского объекта в запросах к серверу ГАР."""
 
     @property
     @abstractmethod
     def _default_hierarchy(self):
-        """Вид иерархии, используемый по умолчанию"""
+        """Вид иерархии, используемый по умолчанию."""
 
     def __init__(self, *args, **kwargs):
         super(ParentFilterMixin, self).__init__(*args, **kwargs)
@@ -400,16 +428,11 @@ class AddressObjectLoaderBase(ParentFilterMixin, LoaderBase):
     @property
     @abstractmethod
     def _levels(self):
-        """Уровни адресных объектов, для которых нужно искать данные в ГАР.
-
-        :rtype: tuple
-        """
+        """Уровни адресных объектов, для которых нужно искать данные в ГАР."""
 
     def _get_params(self):
-        """Возвращает параметры запроса к серверу ГАР.
+        """Возвращает параметры запроса к серверу ГАР."""
 
-        :rtype: dict
-        """
         result = super(AddressObjectLoaderBase, self)._get_params()
 
         if self._levels:
@@ -439,9 +462,11 @@ class AddressObjectLoader(AddressObjectLoaderBase):
     def __init__(self, filter_string, levels=None, typenames=None, **kwargs):
         """Инициализация экземпляра класса.
 
-        :param unicode filter_string: Строка для фильтрации объектов.
-        :param levels: Уровни адресных объектов.
+        Args:
+            filter_string: Строка для фильтрации объектов.
+            levels: Уровни адресных объектов.
         """
+
         super(AddressObjectLoader, self).__init__(filter_string, **kwargs)
 
         self._levels = levels
@@ -457,9 +482,7 @@ class AddressObjectLoader(AddressObjectLoaderBase):
 
 
 class PlaceLoader(AddressObjectLoaderBase):
-    """
-    Загрузчик сведений о населенных пунктах
-    """
+    """Загрузчик сведений о населенных пунктах."""
 
     _levels = GAR_LEVELS_PLACE
 
@@ -467,17 +490,13 @@ class PlaceLoader(AddressObjectLoaderBase):
 
     @property
     def _filter_param(self):
-        """Query-параметр для фильтрации.
+        """Query-параметр для фильтрации."""
 
-        :rtype: str
-        """
         return 'name_with_parents'
 
     def _get_params(self):
-        """Возвращает параметры запроса к серверу ГАР.
+        """Возвращает параметры запроса к серверу ГАР."""
 
-        :rtype: dict
-        """
         filter_param = self._filter_param
 
         if self.exact:
@@ -497,9 +516,7 @@ class PlaceLoader(AddressObjectLoaderBase):
 
 
 class StreetLoader(AddressObjectLoaderBase):
-    """
-    Загрузчик сведений об улицах.
-    """
+    """Загрузчик сведений об улицах."""
 
     _levels = GAR_LEVELS_STREET
 
@@ -507,17 +524,13 @@ class StreetLoader(AddressObjectLoaderBase):
 
     @property
     def _filter_param(self):
-        """Query-параметр для фильтрации.
+        """Query-параметр для фильтрации."""
 
-        :rtype: str
-        """
         return 'name_with_typename'
 
 
 class HouseLoader(ParentFilterMixin, LoaderBase):
-    """
-    Загрузчик сведений о зданиях.
-    """
+    """Загрузчик сведений о зданиях."""
 
     _default_hierarchy = GAR_HIERARCHY_MUN
 
@@ -541,10 +554,10 @@ class HouseLoader(ParentFilterMixin, LoaderBase):
     def _split_number(number):
         """Разделяет номер на целочисленную и буквенную части.
 
-        :param unicode number: Номер дома/корпуса/строения.
-
-        :rtype: tuple
+        Args:
+            number: Номер дома/корпуса/строения.
         """
+
         int_part = ''.join(ch for ch in number if ch.isdigit())
         str_part = number[len(int_part):]
 
@@ -552,12 +565,12 @@ class HouseLoader(ParentFilterMixin, LoaderBase):
 
 
 class SteadLoader(ParentFilterMixin, LoaderBase):
-    """
-    Загрузчик сведений о земельных участках.
-    """
+    """Загрузчик сведений о земельных участках."""
 
     _default_hierarchy = GAR_HIERARCHY_MUN
 
+    _mapper_class = SteadMapper
+
     @property
     def _path(self):
         return '/steads/'
@@ -570,15 +583,49 @@ class SteadLoader(ParentFilterMixin, LoaderBase):
         return True
 
     def _sort_key(self, object_data):
-        return object_data['stead_number'] or ''
+        return object_data.get('stead_number', object_data.get('number')) or ''
 
     @staticmethod
     def _split_number(number):
         """Разделяет номер на целочисленную и буквенную части.
 
-        :param unicode number: Номер земельного участка.
+        Args:
+            number: Номер земельного участка.
+        """
 
-        :rtype: tuple
+        int_part = ''.join(ch for ch in number if ch.isdigit())
+        str_part = number[len(int_part):]
+
+        return int(int_part) if int_part else -1, str_part
+
+
+class ApartmentLoader(ParentFilterMixin, LoaderBase):
+    """Загрузчик сведений о земельных участках."""
+
+    _default_hierarchy = GAR_HIERARCHY_MUN
+
+    _mapper_class = ApartmentMapper
+
+    @property
+    def _path(self):
+        return '/apartments/'
+
+    @property
+    def _filter_param(self):
+        return 'number'
+
+    def _filter(self, object_data):
+        return True
+
+    def _sort_key(self, object_data):
+        return object_data['number'] or ''
+
+    @staticmethod
+    def _split_number(number):
+        """Разделяет номер на целочисленную и буквенную части.
+
+        Args:
+            number: Номер земельного участка.
         """
 
         int_part = ''.join(ch for ch in number if ch.isdigit())
@@ -609,8 +656,6 @@ class UIHouseLoader(HouseLoader):
               ``filter_string``;
             * в аргументе ``filter_string`` конструктора класса было передано
               значение ``None``.
-
-        :rtype: bool
         """
         filter_string_lower = self.filter_string.lower()
 
@@ -660,8 +705,6 @@ class UISteadLoader(SteadLoader):
               указанной в аргументе ``filter_string``;
             * в аргументе ``filter_string`` конструктора класса было передано
               значение ``None``.
-
-        :rtype: bool
         """
 
         filter_string_lower = self.filter_string.lower()
@@ -689,12 +732,15 @@ def get_address_object(obj_id, timeout=None):
 
     Если адресный объект не найден, возвращает ``None``.
 
-    :param obj_id: ObjectID/GUID адресного объекта ГАР.
-    :param float timeout: timeout запроса к серверу ГАР в секундах.
+    Args:
+        obj_id: ObjectID/GUID адресного объекта ГАР.
+        timeout: timeout запроса к серверу ГАР в секундах.
 
-    :rtype: m3_gar_client.data.AddressObject or NoneType
+    Returns:
+        Адресный объект
 
-    :raises requests.ConnectionError: если не удалось соединиться с сервером ГАР
+    Exceptions:
+        requests.ConnectionError: если не удалось соединиться с сервером ГАР
     """
     result = None
 
@@ -718,13 +764,13 @@ def find_address_objects(
 ):
     """Возвращает адресные объекты, соответствующие параметрам поиска.
 
-    :param unicode filter_string: Строка поиска.
-    :param levels: Уровни адресных объектов, среди которых нужно осуществлять поиск.
-    :param parent_id: ID родительского объекта.
-    :param float timeout: Timeout запросов к серверу ГАР в секундах.
-
-    :rtype: generator
+    Args:
+        filter_string: Строка поиска.
+        levels: Уровни адресных объектов, среди которых нужно осуществлять поиск.
+        parent_id: ID родительского объекта.
+        timeout: Timeout запросов к серверу ГАР в секундах.
     """
+
     return AddressObjectLoader(
         filter_string,
         levels=levels,
@@ -734,14 +780,40 @@ def find_address_objects(
     ).load_results()
 
 
+def get_stead(stead_id, timeout=None):
+    """
+    Возвращает информацию о земельном участке по его ID в ГАР.
+
+    Args:
+        stead_id: ID земельного участка.
+        timeout: Timeout запросов к серверу ГАР в секундах.
+
+    Returns:
+        Объект m3_gar_client.data.House
+    """
+
+    assert stead_id is not None
+
+    response = server.get('/steads/{}/'.format(stead_id), timeout=timeout)
+
+    if response and response.status_code == http_client.OK:
+        response_data = response.json()
+        mapped_data = map_object_data(SteadMapper, response_data)
+        result = House(**mapped_data)
+    else:
+        result = None
+
+    return result
+
+
 def get_house(house_id, timeout=None):
     """Возвращает информацию о здании по его ID в ГАР.
 
-    :param house_id: ID здания.
-    :param float timeout: Timeout запросов к серверу ГАР в секундах.
-
-    :rtype: m3_gar_client.data.House
+    Args:
+        house_id: ID здания.
+        timeout: Timeout запросов к серверу ГАР в секундах.
     """
+
     assert house_id is not None
 
     response = server.get('/houses/{}/'.format(house_id), timeout=timeout)
@@ -759,14 +831,14 @@ def get_house(house_id, timeout=None):
 def find_house(house_number='', parent_id=None, building_number=None, structure_number=None, timeout=None):
     """Возвращает информацию о здании по его номеру.
 
-    :param unicode house_number: Номер дома.
-    :param parent_id: ID родительского объекта.
-    :param unicode building_number: Номер корпуса.
-    :param unicode structure_number: Номер строения.
-    :param float timeout: Timeout запросов к серверу ГАР в секундах.
-
-    :rtype: m3_gar_client.data.House or NoneType
+    Args:
+        house_number: Номер дома.
+        parent_id: ID родительского объекта.
+        building_number: Номер корпуса.
+        structure_number: Номер строения.
+        timeout: Timeout запросов к серверу ГАР в секундах.
     """
+
     houses = HouseLoader(
         house_number,
         parent_id=parent_id,
@@ -789,11 +861,60 @@ def find_house(house_number='', parent_id=None, building_number=None, structure_
     return result
 
 
-def flatten_object_data(raw_object_data):
-    """Преобразует данные объекта ГАР к "плоскому" виду
+def find_stead(number='', parent_id=None, timeout=None):
+    """Возвращает информацию об участке по его номеру.
 
-    :param dict raw_object_data: Необработанные данные объекта ГАР, полученные с сервера m3-rest-gar.
+    :param unicode number: Номер участка.
+    :param parent_id: ID родительского объекта.
+    :param float timeout: Timeout запросов к серверу ГАР в секундах.
+
+    :rtype: m3_gar_client.data.Stead or NoneType
     """
+    steads = SteadLoader(
+        number,
+        parent_id=parent_id,
+        timeout=timeout,
+    ).load()
+
+    if len(steads) == 1:
+        result = Stead(**steads[0])
+    else:
+        result = None
+
+    return result
+
+
+def find_apartment(number='', parent_id=None, timeout=None):
+    """Возвращает информацию о помещении по его номеру.
+
+    Args:
+        housenum: Номер квартиры.
+        parent_id: ID родительского объекта.
+        timeout: Timeout запросов к серверу ГАР в секундах.
+    """
+
+    apartments = ApartmentLoader(
+        number,
+        parent_id=parent_id,
+        exact=True,
+        timeout=timeout,
+    ).load()
+
+    if len(apartments) == 1:
+        result = Apartment(**apartments[0])
+    else:
+        result = None
+
+    return result
+
+
+def flatten_object_data(raw_object_data):
+    """Преобразует данные объекта ГАР к "плоскому" виду.
+
+    Args:
+        raw_object_data: Необработанные данные объекта ГАР, полученные с сервера m3-rest-gar.
+    """
+
     flat_data = {}
 
     for key, value in iteritems(raw_object_data):
@@ -820,11 +941,13 @@ def flatten_object_data(raw_object_data):
 
 
 def map_object_data(mapper_class, raw_object_data):
-    """Выполняет маппинг сырых данных, полученных с сервера m3-rest-gar
+    """Выполняет маппинг сырых данных, полученных с сервера m3-rest-gar.
 
-    :param dict raw_object_data: Необработанные данные объекта ГАР, полученные с сервера m3-rest-gar.
-    :param class ObjectMapper mapper_class: класс-маппер.
+    Args:
+        mapper_class: Класс-маппер.
+        raw_object_data: Необработанные данные объекта ГАР, полученные с сервера m3-rest-gar.
     """
+
     flat_data = flatten_object_data(raw_object_data)
     mapped_data = mapper_class(flat_data)
 
