@@ -1,24 +1,40 @@
 # coding: utf-8
-from __future__ import absolute_import
-from __future__ import unicode_literals
+from __future__ import (
+    absolute_import,
+    unicode_literals,
+)
 
-from abc import ABCMeta
-from abc import abstractproperty
-from collections import Mapping
-from collections import MutableMapping
-from collections import defaultdict
-from collections import namedtuple
-from datetime import date
-from datetime import datetime
-from functools import partial
-from uuid import UUID
+from abc import (
+    ABCMeta,
+    abstractproperty,
+)
+from collections import (
+    Mapping,
+    MutableMapping,
+    defaultdict,
+    namedtuple,
+)
+from datetime import (
+    date,
+    datetime,
+)
+from functools import (
+    partial,
+)
+from uuid import (
+    UUID,
+)
 
-from six import iteritems
-from six import iterkeys
-from six import text_type
-from six import with_metaclass
+from six import (
+    iteritems,
+    iterkeys,
+    text_type,
+    with_metaclass,
+)
 
-from m3_gar_constants import GAR_LEVELS
+from m3_gar_constants import (
+    GAR_LEVELS,
+)
 
 
 FieldDescriptor = namedtuple('FieldDescriptor', [
@@ -61,8 +77,8 @@ class ObjectMeta(ABCMeta):
 
 
 class ObjectBase(with_metaclass(ObjectMeta, object)):
-    """
-    Базовый класс для объектов ГАР.
+    """Базовый класс для объектов ГАР.
+
     Обеспечивает неизменяемость данных (объекты только для чтения).
     """
 
@@ -94,15 +110,11 @@ class ObjectBase(with_metaclass(ObjectMeta, object)):
 
 # dict в списке базовых классов нужен для правильной обработки данных в M3.
 class ObjectDictAdapter(Mapping, dict):
-    """
-    Адаптер для объектов ГАР, преобразующий их к словарям.
-    """
+    """Адаптер для объектов ГАР, преобразующий их к словарям."""
 
     def __init__(self, obj):  # pylint: disable=super-init-not-called
-        """Инициализация экземпляра класса.
+        """Инициализация экземпляра класса."""
 
-        :type obj: m3_gar_client.data.ObjectBase
-        """
         assert isinstance(obj, ObjectBase), type(obj)
 
         self._obj = obj
@@ -217,9 +229,7 @@ def _choices(valid_values, value_type, raw_value):
 
 
 class AddressObject(ObjectBase):
-    """
-    Адресный объект.
-    """
+    """Адресный объект."""
 
     #: Поля объекта и признак обязательности значения.
     fields = {
@@ -372,9 +382,7 @@ class AddressObject(ObjectBase):
 
 
 class House(ObjectBase):
-    """
-    Объект здания (дома).
-    """
+    """Объект здания (дома)."""
 
     fields = {
         'id': FieldDescriptor(
@@ -482,6 +490,11 @@ class House(ObjectBase):
             required=False,
             description='Родительский guid в муниципальной иерархии'
         ),
+        'level': FieldDescriptor(
+            data_type=partial(_choices, GAR_LEVELS, _int),
+            required=True,
+            description='Уровень объекта.',
+        ),
         'number': FieldDescriptor(
             data_type=_int,
             required=False,
@@ -492,30 +505,204 @@ class House(ObjectBase):
             required=False,
             description=''
         ),
+        'house_type_full': FieldDescriptor(
+            data_type=_unicode_or_empty,
+            required=False,
+            description=''
+        ),
         'building_type': FieldDescriptor(
             data_type=_unicode_or_empty,
             required=False,
             description=''
         ),
+        'building_type_full': FieldDescriptor(
+            data_type=_unicode_or_empty,
+            required=False,
+            description=''
+        ),
         'structure_type': FieldDescriptor(
             data_type=_unicode_or_empty,
             required=False,
             description=''
         ),
+        'structure_type_full': FieldDescriptor(
+            data_type=_unicode_or_empty,
+            required=False,
+            description=''
+        ),
+    }
+
+
+class Stead(ObjectBase):
+    """Объект участка."""
+
+    fields = {
+        'id': FieldDescriptor(
+            data_type=_int,
+            required=True,
+            description='Уникальный идентификатор записи дома',
+        ),
+        'obj_id': FieldDescriptor(
+            data_type=_int,
+            required=True,
+            description='Глобальный уникальный идентификатор дома',
+        ),
+        'guid': FieldDescriptor(
+            data_type=_uuid,
+            required=True,
+            description='UUID адресного объекта.',
+        ),
+        'ifns_fl_code': FieldDescriptor(
+            data_type=_unicode_or_empty,
+            required=False,
+            description='Код ИФНС для физических лиц.',
+        ),
+        'ifns_fl_territorial_district_code': FieldDescriptor(
+            data_type=_unicode_or_empty,
+            required=False,
+            description='Код территориального участка ИФНС ФЛ.',
+        ),
+        'ifns_ul_code': FieldDescriptor(
+            data_type=_unicode_or_empty,
+            required=False,
+            description='Код ИФНС для юридических лиц.',
+        ),
+        'ifns_ul_territorial_district_code': FieldDescriptor(
+            data_type=_unicode_or_empty,
+            required=False,
+            description='Код территориального участка ИФНС ЮЛ.',
+        ),
+        'okato': FieldDescriptor(
+            data_type=_unicode_or_empty,
+            required=False,
+            description='ОКАТО.',
+        ),
+        'oktmo': FieldDescriptor(
+            data_type=_unicode_or_empty,
+            required=False,
+            description='ОКТМО.',
+        ),
+        'postal_code': FieldDescriptor(
+            data_type=_unicode_or_empty,
+            required=False,
+            description='Почтовый индекс',
+        ),
+        'level': FieldDescriptor(
+            data_type=partial(_choices, GAR_LEVELS, _int),
+            required=True,
+            description='Уровень объекта.',
+        ),
+        'number': FieldDescriptor(
+            data_type=_unicode,
+            required=True,
+            description='Номер',
+        ),
+        'date_of_creation': FieldDescriptor(
+            data_type=_date,
+            required=True,
+            description='Начало действия записи',
+        ),
+        'date_of_update': FieldDescriptor(
+            data_type=_date,
+            required=True,
+            description='Дата  внесения (обновления) записи',
+        ),
+        'date_of_end': FieldDescriptor(
+            data_type=_date,
+            required=True,
+            description='Окончание действия записи',
+        ),
+        'region_code': FieldDescriptor(
+            data_type=_int,
+            required=True,
+            description='Код региона',
+        ),
+        'adm_parent_obj_id': FieldDescriptor(
+            data_type=_int,
+            required=False,
+            description='Родительский obj_id в административной иерархии'
+        ),
+        'adm_parent_guid': FieldDescriptor(
+            data_type=_uuid,
+            required=False,
+            description='Родительский guid в административной иерархии'
+        ),
+        'mun_parent_obj_id': FieldDescriptor(
+            data_type=_int,
+            required=False,
+            description='Родительский obj_id в муниципальной иерархии'
+        ),
+        'mun_parent_guid': FieldDescriptor(
+            data_type=_uuid,
+            required=False,
+            description='Родительский guid в муниципальной иерархии'
+        ),
+    }
+
+
+class Apartment(ObjectBase):
+    """Объект помещения."""
+
+    fields = {
+        'id': FieldDescriptor(
+            data_type=_int,
+            required=True,
+            description='Уникальный идентификатор записи дома',
+        ),
+        'obj_id': FieldDescriptor(
+            data_type=_int,
+            required=True,
+            description='Глобальный уникальный идентификатор дома',
+        ),
+        'guid': FieldDescriptor(
+            data_type=_uuid,
+            required=True,
+            description='UUID адресного объекта.',
+        ),
+        'number': FieldDescriptor(
+            data_type=_unicode,
+            required=True,
+            description='Номер',
+        ),
+        'apart_type': FieldDescriptor(
+            data_type=_unicode,
+            required=True,
+            description='Номер',
+        ),
+        'level': FieldDescriptor(
+            data_type=partial(_choices, GAR_LEVELS, _int),
+            required=True,
+            description='Уровень объекта.',
+        ),
+        'adm_parent_obj_id': FieldDescriptor(
+            data_type=_int,
+            required=False,
+            description='Родительский obj_id в административной иерархии'
+        ),
+        'adm_parent_guid': FieldDescriptor(
+            data_type=_uuid,
+            required=False,
+            description='Родительский guid в административной иерархии'
+        ),
+        'mun_parent_obj_id': FieldDescriptor(
+            data_type=_int,
+            required=False,
+            description='Родительский obj_id в муниципальной иерархии'
+        ),
+        'mun_parent_guid': FieldDescriptor(
+            data_type=_uuid,
+            required=False,
+            description='Родительский guid в муниципальной иерархии'
+        ),
     }
 
 
 class ObjectMapper(with_metaclass(ABCMeta, MutableMapping)):
-    """
-    Обертка над словарями, преобразующая ключи.
-    """
+    """Обертка над словарями, преобразующая ключи."""
 
     @abstractproperty
     def fields_map(self):
-        """Список соответствия ключей.
-
-        :rtype: dict
-        """
+        """Список соответствия ключей."""
 
     def __init__(self, data):  # pylint: disable=super-init-not-called
         assert isinstance(data, dict), type(data)
